Bifrost: Unitig< T > Class Template Reference

Bifrost

Public Member Functions | Data Fields
Unitig< T > Class Template Reference

Represent a unitig which is a vertex of the Compacted de Bruijn graph. More...

## Public Member Functions
const T * | getData () const
| Return a constant pointer to the data associated with the unitig. More...

## Data Fields
T | data
| Data associated with the unitigs of the graph.

## Detailed Description

### template<typename T>
class Unitig< T >

Represent a unitig which is a vertex of the Compacted de Bruijn graph.

The first template argument T is the type of data associated with the unitigs of the graph.

## Member Function Documentation

## ◆ getData()

template<typename T>

const T* Unitig< T >::getData | ( |  | ) | const
| inline

Return a constant pointer to the data associated with the unitig.

Returns
  a constant pointer to the data associated with the unitig.

The documentation for this class was generated from the following file:

- src/Unitig.hpp